SystemOrganization addCategory: #'DeprecatedPreferences-Browser'!
SystemOrganization addCategory: #'DeprecatedPreferences-Core'!
SystemOrganization addCategory: #'DeprecatedPreferences-Users'!

Object subclass: #Preference
	instanceVariableNames: 'name value defaultValue helpString localToProject categoryList changeInformee changeSelector viewRegistry'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DeprecatedPreferences-Core'!

!Preference commentStamp: '<historical>' prior: 0!
Represents a true/false flag that is under user control and which can be interrogated by a call to Preferences
	viewRegistry		the registry of the classes responsible for building my view
	name 				a symbol, the formal name of the preference.
	value				a boolean, the current value
	defaultValue		the default value of the preference
	helpString 			string or text, constituting the help message
	localToProject		boolean, whether each project holds its own version
	categoryList			list of categories under which to offer this
	changeInformee 	whom, if anyone, to inform if the value changes:
	changeSelector 		what selector to send to the changeInformee when the value changes!

!Preference methodsFor: 'menu' stamp: 'sw 4/12/2001 23:42'!
categoryList
	"Answer the categoryList"

	^ categoryList! !

!Preference methodsFor: 'initialization' stamp: 'sw 4/29/2001 23:51'!
categoryList: aList
	"Set the receiver's categoryList"

	categoryList := aList! !

!Preference methodsFor: 'change notification' stamp: 'michael.rueger 4/27/2009 18:00'!
changeInformee

	^changeInformee! !

!Preference methodsFor: 'initialization' stamp: 'lr 3/14/2010 21:13'!
changeInformee: informee
	"Set the object to be informed when my value changes"

	changeInformee := (informee == nil or: [ informee == #nil ])
		ifTrue: [ nil ]
		ifFalse: [ 
			(informee isKindOf: Symbol)
				ifTrue: [ Smalltalk globals at: informee ]
				ifFalse: [ informee ] ]! !

!Preference methodsFor: 'change notification' stamp: 'sw 4/12/2001 01:39'!
changeInformee: informee changeSelector: aSelector
	"Set the changeInformee and changeSelector as specified"

	changeInformee := informee.
	changeSelector := aSelector! !

!Preference methodsFor: 'menu' stamp: 'sw 4/13/2001 00:01'!
copyName
	"Copy the name of the given preference to the clipboard"

	Clipboard clipboardText: name asString asText! !

!Preference methodsFor: 'value' stamp: 'AlainPlantec 1/8/2010 00:14'!
defaultValue
	"Answer this preference's defaultValue "

	^ defaultValue! !

!Preference methodsFor: 'value' stamp: 'sw 4/18/2002 12:15'!
defaultValue: aValue
	"Set the receiver's defaultValue"

	defaultValue := aValue.! !

!Preference methodsFor: 'menu' stamp: 'sw 4/13/2001 00:04'!
helpString
	"Answer the help string provided for the receiver"

	^ helpString ifNil: ['no help available']! !

!Preference methodsFor: 'value' stamp: 'AlainPlantec 12/11/2009 08:25'!
isMigratedToSetting
	"hack which is to make the old Preferences browser work with
	the new setting framework - Alain Plantec"
	| selector |
	selector := (self name , 'Setting:') asSymbol.
	^ (Preferences respondsTo: selector)
		and: [(Preferences class methodsInCategory: #'settings-migration')
				includes: selector]! !

!Preference methodsFor: 'value' stamp: 'AlainPlantec 12/11/2009 08:29'!
isNotMigratedToSetting
	"hack to show which preferences are not migrated - Alain
	Plantec"
	| selector |
	selector := self name asSymbol.
	^ (Preferences respondsTo: selector)
		and: [(Preferences class methodsInCategory: #'settings-no-migration')
				includes: selector]! !

!Preference methodsFor: 'testing' stamp: 'ar 9/27/2005 21:50'!
isObsolete
	^(changeInformee class isObsolete or:[changeInformee isBehavior and:[changeInformee isObsolete]])! !

!Preference methodsFor: 'local to project' stamp: 'sw 4/10/2001 12:37'!
isProjectLocalString
	"Answer a string representing whether sym is a project-local preference or not"

	| aStr |
	aStr :=  'each project has its own setting'.
	^ localToProject
		ifTrue:
			['<yes>', aStr]
		ifFalse:
			['<no>', aStr]! !

!Preference methodsFor: 'value' stamp: 'AlainPlantec 12/11/2009 08:26'!
isSemiMigratedToSetting
	"hack to show which preferences are kept (class variable) but
	with no setting - Alain Plantec"
	| selector |
	selector := (self name , 'Setting') asSymbol.
	^ (Preferences  respondsTo: selector)
		and: [(Preferences class methodsInCategory: #'settings-semi-migration')
				includes: selector]! !

!Preference methodsFor: 'local to project' stamp: 'sw 4/10/2001 01:14'!
localToProject
	"Answer whether this preference is project-local"

	^ localToProject! !

!Preference methodsFor: 'menu' stamp: 'sw 4/10/2001 15:02'!
name
	"Answer this preference's name"

	^ name! !

!Preference methodsFor: 'initialization' stamp: 'lr 3/14/2010 21:13'!
name: aName defaultValue: aValue helpString: aString localToProject: projectBoolean categoryList: aList changeInformee: informee changeSelector: aChangeSelector viewRegistry: aViewRegistry
	"Initialize the preference from the given values.  There is an extra tolerence here for the symbols #true, #false, and #nil, which are interpreted, when appropriate, as meaning true, false, and nil"

	name := aName asSymbol.
	defaultValue := aValue.
	aValue = #true
		ifTrue: [ defaultValue := true ].
	aValue = #false
		ifTrue: [ defaultValue := false ].
	value := defaultValue.
	helpString := aString.
	localToProject := projectBoolean == true or: [ projectBoolean = #true ].
	viewRegistry := aViewRegistry.
	categoryList := (aList ifNil: [ OrderedCollection with: #unclassified ]) collect: [ :elem | elem asSymbol ].
	changeInformee := (informee == nil or: [ informee == #nil ])
		ifTrue: [ nil ]
		ifFalse: [ 
			(informee isKindOf: Symbol)
				ifTrue: [ Smalltalk globals at: informee ]
				ifFalse: [ informee ] ].
	changeSelector := aChangeSelector! !

!Preference methodsFor: 'change notification' stamp: 'AlainPlantec 12/17/2009 10:15'!
notifyInformeeOfChange
	"If there is a changeInformee, notify her that I have changed value"
	(Preferences respondsTo: (self name, 'Setting:') asSymbol) 
		ifFalse: [changeInformee ifNotNil: [changeInformee perform: changeSelector]]! !

!Preference methodsFor: 'value' stamp: 'AlainPlantec 12/8/2009 10:58'!
preferenceValue
	"Answer the current value of the preference"

	^ self settingValue! !

!Preference methodsFor: 'value' stamp: 'AlainPlantec 12/8/2009 10:29'!
preferenceValue: aValue
	"set the value as indicated, and invoke the change selector if appropriate"

	| oldValue |
	self settingValue: aValue.
	oldValue := value.
	value := aValue.
	oldValue ~~ value ifTrue:
		[self notifyInformeeOfChange]! !

!Preference methodsFor: 'debugging' stamp: 'sw 4/13/2001 00:05'!
printOn: aStream
	"Print a string decribing the receiver to the given stream"

	super printOn: aStream.
	aStream nextPutAll: name storeString, ' ', value storeString! !

!Preference methodsFor: 'value' stamp: 'AlainPlantec 12/8/2009 10:29'!
rawValue: aValue
	"set the value as indicated, with no side effects"

	self settingValue: aValue.
	value := aValue.! !

!Preference methodsFor: 'user interface' stamp: 'hpt 9/26/2004 16:58'!
representativeButtonWithColor: aColor inPanel: aPanel
	| view |
	view := self viewForPanel: aPanel.
	^view ifNotNil: [view representativeButtonWithColor: aColor inPanel: aPanel]! !

!Preference methodsFor: 'value' stamp: 'AlainPlantec 12/8/2009 10:29'!
restoreDefaultValue
	"restore the default value to the preference"

	self settingValue: defaultValue.
	value := defaultValue! !

!Preference methodsFor: 'value' stamp: 'AlainPlantec 12/11/2009 08:24'!
settingValue
	"hack which is to make the old Preferences browser work with
	the new setting framework - Alain Plantec"
	^ (Preferences respondsTo: (self name , 'Setting') asSymbol)
		ifTrue: [Preferences perform: (self name , 'Setting') asSymbol]
		ifFalse: [value] ! !

!Preference methodsFor: 'value' stamp: 'AlainPlantec 12/17/2009 10:12'!
settingValue: aValue
	"hack which is to make the old Preferences browser work with the new setting framework - Alain Plantec"
	(Preferences respondsTo: (self name, 'Setting:') asSymbol) 
		ifTrue: [Preferences perform: (self name, 'Setting:') asSymbol with: aValue. 
			^ true].
	^ false! !

!Preference methodsFor: 'change notification' stamp: 'AlainPlantec 12/17/2009 10:19'!
settingsMigrationCheck
	(Preferences respondsTo: (self name, 'Setting:') asSymbol) 
		ifTrue: [changeInformee 
			ifNotNil: [Transcript show: changeInformee name, ' '.
				Transcript show: changeSelector, String cr]].! !

!Preference methodsFor: 'value' stamp: 'AlainPlantec 12/8/2009 10:29'!
togglePreferenceValue
	"Toggle whether the value of the preference. Self must be a boolean preference."
	value := value not.
	self settingValue: value.
	self notifyInformeeOfChange! !

!Preference methodsFor: 'local to project' stamp: 'alain.plantec 6/6/2009 14:23'!
toggleProjectLocalness
	"Toggle whether the preference should be held project-by-project or globally"

	localToProject := localToProject not.
! !

!Preference methodsFor: 'user interface' stamp: 'hpt 9/26/2004 15:42'!
viewClassForPanel: aPreferencePanel
	^self viewRegistry viewClassFor: aPreferencePanel! !

!Preference methodsFor: 'user interface' stamp: 'hpt 9/26/2004 16:58'!
viewForPanel: aPreferencePanel
	| viewClass |
	viewClass := self viewClassForPanel: aPreferencePanel.
	^viewClass ifNotNil: [viewClass preference: self]! !

!Preference methodsFor: 'user interface' stamp: 'hpt 9/26/2004 15:40'!
viewRegistry
	^viewRegistry! !

!Preference methodsFor: 'user interface' stamp: 'hpt 9/26/2004 15:40'!
viewRegistry: aRegistry
	viewRegistry := aRegistry! !

Object subclass: #Preferences
	instanceVariableNames: ''
	classVariableNames: 'DictionaryOfPreferences Parameters'
	poolDictionaries: ''
	category: 'DeprecatedPreferences-Core'!

!Preferences commentStamp: '<historical>' prior: 0!
A general mechanism to store preference choices.  The default setup treats any symbol as a potential boolean flag; flags unknown to the preference dictionary are always returned as false.  

	To open the control panel:		Preferences openFactoredPanel
	To read how to use the panel (and how to make a preference be per-project):
		 Preferences giveHelpWithPreferences

All messages are on the class side.

To query a a preference:
	Preferences logDebuggerStackToFile
or some people prefer the more verbose
	Preferences valueOfFlag: #logDebuggerStackToFile

You can make up a new preference any time.  Do not define a new message in Preferences class. Accessor methods are compiled automatically when you add a preference as illustrated below:

To add a preference (e.g. in the Postscript of a fileout):
	Preferences addPreference: #samplePreference categories: #(general browsing)
		default: true balloonHelp: 'This is an example of a preference added by a do-it'
		projectLocal: false changeInformee: nil changeSelector: nil.

To change a preference programatically:
	Preferences disable: #logDebuggerStackToFile.
Or to turn it on,
	Preferences enable: #logDebuggerStackToFile.
!

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/10/2009 08:42'!
Curvier
	^ self CurvierSetting
! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/11/2009 07:33'!
CurvierSetting
	^ PolygonMorph curvierByDefault! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/11/2009 07:34'!
CurvierSetting: aBoolean 
	^ PolygonMorph curvierByDefault: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
DPConflict
	^ self
		valueOfFlag: #DPConflict
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
DPDebugging
	^ self
		valueOfFlag: #DPDebugging
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
DPDuplicated
	^ self
		valueOfFlag: #DPDuplicated
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
DPLocal
	^ self
		valueOfFlag: #DPLocal
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
DPLong
	^ self
		valueOfFlag: #DPLong
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
DPOverride
	^ self
		valueOfFlag: #DPOverride
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
DPRecentlyModified
	^ self
		valueOfFlag: #DPRecentlyModified
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
DPRequired
	^ self
		valueOfFlag: #DPRequired
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
DPSuperSend
	^ self
		valueOfFlag: #DPSuperSend
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
DPSupplied
	^ self
		valueOfFlag: #DPSupplied
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
DPUncommented
	^ self
		valueOfFlag: #DPUncommented
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 14:59'!
FreeTypeCacheSize
	^FreeTypeCache current cacheSize ! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:19'!
FreeTypeCacheSizeSetting
	^FreeTypeCache current cacheSize ! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:31'!
FreeTypeCacheSizeSetting: anInteger
	FreeTypeCache current cacheSize:  anInteger! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/8/2009 10:37'!
GlyphContrast
	^ FreeTypeSettings current glyphContrast! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:20'!
GlyphContrastSetting
	^ FreeTypeSettings current glyphContrast! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:37'!
GlyphContrastSetting: aValue
	FreeTypeSettings current glyphContrast: aValue! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 15:08'!
HintingFull
	^ FreeTypeSettings current hintingSymbol = #Full! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:58'!
HintingFullSetting
	^ FreeTypeSettings current hintingSymbol = #Full! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:33'!
HintingFullSetting: aValue
	aValue 
		ifTrue: [FreeTypeSettings current hintingSymbol: #Full]
! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 15:01'!
HintingLight
	^ FreeTypeSettings current hintingSymbol = #Light! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:59'!
HintingLightSetting
	^ FreeTypeSettings current hintingSymbol = #Light! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:34'!
HintingLightSetting: aBoolean
	aBoolean 
		ifTrue: [FreeTypeSettings current hintingSymbol: #Light]
! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 15:01'!
HintingNone
	^ FreeTypeSettings current hintingSymbol = #None! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:59'!
HintingNoneSetting
	^ FreeTypeSettings current hintingSymbol = #None! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:35'!
HintingNoneSetting: aBoolean
	aBoolean 
		ifTrue: [FreeTypeSettings current hintingSymbol: #None]
! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 15:02'!
HintingNormal
	^ FreeTypeSettings current hintingSymbol = #Normal! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:59'!
HintingNormalSetting
	^ FreeTypeSettings current hintingSymbol = #Normal! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:35'!
HintingNormalSetting: aBoolean
	aBoolean 
		ifTrue: [FreeTypeSettings current hintingSymbol: #Normal]
! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 15:02'!
MonitorTypeCRT
	^ FreeTypeSettings current monitorType = #CRT! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:59'!
MonitorTypeCRTSetting
	^ FreeTypeSettings current monitorType = #CRT! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:24'!
MonitorTypeCRTSetting: aBoolean
	aBoolean 
		ifTrue: [FreeTypeSettings current monitorType: #CRT]
		ifFalse: [FreeTypeSettings current monitorType: #LCD]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 15:02'!
MonitorTypeLCD
	^ FreeTypeSettings current monitorType = #LCD! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:59'!
MonitorTypeLCDSetting
	^ FreeTypeSettings current monitorType = #LCD! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:24'!
MonitorTypeLCDSetting: aBoolean
	aBoolean 
		ifTrue: [FreeTypeSettings current monitorType: #LCD]
		ifFalse: [FreeTypeSettings current monitorType: #CRT]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 15:03'!
UpdateFontsAtImageStartup
	^ FreeTypeSettings updateFontsAtImageStartup! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:32'!
UpdateFontsAtImageStartupSetting
	^ FreeTypeSettings updateFontsAtImageStartup! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:32'!
UpdateFontsAtImageStartupSetting: aBoolean
	FreeTypeSettings updateFontsAtImageStartup: aBoolean! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/18/2009 16:48'!
aaFontsColormapDepth
	"Adjust balance between colored AA text quality (especially if subpixel AA is used) and space / performance.
	5 is optimal quality. Each colorMap takes 128kB of RAM, and takes several seconds to build.
	4 is a reasonable balance. Each colorMap takes 16kB of RAM and builds fast on a fast machine.
	3 is good for slow hardware or memory restrictions. Each colorMap takes 2 kb of RAM."
	^ Color aaFontsColormapDepth! !

!Preferences class methodsFor: 'parameters' stamp: 'sw 2/24/1999 12:26'!
acceptAnnotationsFrom: aSystemWindow
	"This intricate extraction is based on the precise structure of the annotation-request window.  Kindly avert your eyes."
	| aList |
	aList := aSystemWindow paneMorphs first firstSubmorph submorphs collect:
		[:m |  m contents asSymbol].
	self defaultAnnotationRequests: aList
	! !

!Preferences class methodsFor: 'add preferences' stamp: 'StephaneDucasse 7/18/2010 11:21'!
addBooleanPreference: prefSymbol categories: categoryList default: defaultValue balloonHelp: helpString 
	"Add an item repreesenting the given preference symbol to the system. Default view for this preference is boolean to keep backward compatibility"

	! !

!Preferences class methodsFor: 'add preferences' stamp: 'StephaneDucasse 7/18/2010 11:21'!
addBooleanPreference: prefSymbol category: categorySymbol default: defaultValue balloonHelp: helpString 
	"Add an item repreesenting the given preference symbol to the system. Default view for this preference is boolean to keep backward compatibility"

	! !

!Preferences class methodsFor: 'add preferences' stamp: 'StephaneDucasse 7/18/2010 11:21'!
addColorPreference: prefSymbol categories: categoryList default: defaultValue balloonHelp: helpString 
	"Add an item repreesenting the given preference symbol to the system. Default view for this preference is boolean to keep backward compatibility"

	! !

!Preferences class methodsFor: 'add preferences' stamp: 'StephaneDucasse 7/18/2010 11:21'!
addColorPreference: prefSymbol category: categorySymbol default: defaultValue balloonHelp: helpString 
	"Add an item repreesenting the given preference symbol to the system. Default view for this preference is boolean to keep backward compatibility"

	! !

!Preferences class methodsFor: 'add preferences' stamp: 'StephaneDucasse 7/18/2010 11:21'!
addFontPreference: prefSymbol categories: categoryList default: defaultValue balloonHelp: helpString 
	"Add an item repreesenting the given preference symbol to the system. Default view for this preference is boolean to keep backward compatibility"

	! !

!Preferences class methodsFor: 'add preferences' stamp: 'StephaneDucasse 7/18/2010 11:21'!
addFontPreference: prefSymbol category: categorySymbol default: defaultValue balloonHelp: helpString 
	"Add an item repreesenting the given preference symbol to the system. Default view for this preference is boolean to keep backward compatibility"

	! !

!Preferences class methodsFor: 'misc' stamp: 'sw 10/6/1999 15:20'!
addModelItemsToWindowMenu: aMenu
	aMenu addLine.
	aMenu add: 'restore default preference settings' target: self action: #chooseInitialSettings.
	aMenu add: 'restore default text highlighting' target: self action: #initializeTextHighlightingParameters! !

!Preferences class methodsFor: 'add preferences' stamp: 'StephaneDucasse 7/18/2010 11:21'!
addNumericPreference: prefSymbol categories: categoryList default: defaultValue balloonHelp: helpString 
	"Add an item repreesenting the given preference symbol to the system. "

! !

!Preferences class methodsFor: 'add preferences' stamp: 'StephaneDucasse 7/18/2010 11:21'!
addNumericPreference: prefSymbol category: categorySymbol default: defaultValue balloonHelp: helpString 
	"Add an item repreesenting the given preference symbol to the system."

	! !

!Preferences class methodsFor: 'add preferences' stamp: 'hpt 9/26/2004 16:05'!
addPreference: prefSymbol categories: categoryList default: defaultValue balloonHelp: helpString 
	"Add an item repreesenting the given preference symbol to the system. Default view for this preference is boolean to keep backward compatibility"
	self addBooleanPreference: prefSymbol categories: categoryList default: defaultValue balloonHelp: helpString.! !

!Preferences class methodsFor: 'add preferences' stamp: 'AlainPlantec 12/17/2009 21:56'!
addPreference: aName categories: categoryList default: aValue balloonHelp: helpString projectLocal: localBoolean changeInformee: informeeSymbol changeSelector: aChangeSelector viewRegistry: aViewRegistry 
	"Add or replace a preference as indicated.  Reuses the preexisting Preference object for this symbol, if there is one, so that UI artifacts that interact with it will remain valid."

	| aPreference aPrefSymbol |
	aPrefSymbol := aName asSymbol.
	aPreference := self dictionaryOfPreferences  at:aPrefSymbol
				 ifAbsent:[Preference new].
	aPreference 
		 name:aPrefSymbol
		 defaultValue:aValue
		 helpString:helpString
		 localToProject:localBoolean
		 categoryList:categoryList
		 changeInformee:informeeSymbol
		 changeSelector:aChangeSelector
		 viewRegistry:aViewRegistry.
	self dictionaryOfPreferences  at:aPrefSymbol  put:aPreference.
	"self  compileAccessMethodForPreference:aPreference"! !

!Preferences class methodsFor: 'add preferences' stamp: 'hpt 9/26/2004 16:05'!
addPreference: prefSymbol category: categorySymbol default: defaultValue balloonHelp: helpString 
	"Add the given preference, putting it in the given category, with the given default value, and with the given balloon help. It assumes boolean preference for backward compatibility"

	self addBooleanPreference: prefSymbol category: categorySymbol default: defaultValue balloonHelp: helpString.! !

!Preferences class methodsFor: 'add preferences' stamp: 'StephaneDucasse 7/18/2010 11:21'!
addTextPreference: prefSymbol categories: categoryList default: defaultValue balloonHelp: helpString 
	"Add an item repreesenting the given preference symbol to the system. Default view for this preference is boolean to keep backward compatibility"

	! !

!Preferences class methodsFor: 'add preferences' stamp: 'StephaneDucasse 7/18/2010 11:21'!
addTextPreference: prefSymbol category: categorySymbol default: defaultValue balloonHelp: helpString 
	"Add an item repreesenting the given preference symbol to the system. Default view for this preference is boolean to keep backward compatibility"

	! !

!Preferences class methodsFor: 'preference-object access' stamp: 'rr 10/1/2005 15:14'!
allPreferenceObjects
	"Answer a list of all the Preference objects registered in the system"

	^ self dictionaryOfPreferences values! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 11:45'!
allowBlockArgumentAssignment

	^ Parser allowBlockArgumentAssignment
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:06'!
allowBlockArgumentAssignmentSetting

	^ Parser allowBlockArgumentAssignment
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:06'!
allowBlockArgumentAssignmentSetting: aBoolean

	Parser allowBlockArgumentAssignment: aBoolean
! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 11:45'!
allowUnderscoreAssignment
	^ Scanner allowUnderscoreAsAssignment
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:59'!
allowUnderscoreAssignmentSetting
	^ Scanner allowUnderscoreAsAssignment
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:07'!
allowUnderscoreAssignmentSetting: aBoolean
	Scanner allowUnderscoreAsAssignment: aBoolean
! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
allwaysShowVScrollBar
	^ self
		valueOfFlag: #allwaysShowVScrollBar
		ifAbsent: [false]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: 'AlainPlantec 12/17/2009 21:40'!
alwaysHideHScrollbar
	^ ScrollPane alwaysHideHScrollbar! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
alwaysShowConnectionVocabulary
	^ self
		valueOfFlag: #alwaysShowConnectionVocabulary
		ifAbsent: [false]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: 'AlainPlantec 12/17/2009 21:40'!
alwaysShowHScrollbar
	^ ScrollPane alwaysShowHScrollbar! !

!Preferences class methodsFor: 'settings-no-migration' stamp: 'AlainPlantec 12/17/2009 21:41'!
alwaysShowVScrollbar
	^ ScrollPane alwaysShowVScrollbar! !

!Preferences class methodsFor: 'parameters' stamp: 'sw 7/12/2001 18:18'!
annotationInfo 
	"Answer a list of pairs characterizing all the available kinds of annotations; in each pair, the first element is a symbol representing the info type, and the second element is a string providing the corresponding balloon help"

	^ #(

		(timeStamp			'The time stamp of the last submission of the method.')
		(firstComment		'The first comment in the method, if any.')
		(masterComment		'The comment at the beginning of the supermost implementor of the method if any.')
		(documentation		'Comment at beginning of the method or, if it has none, comment at the beginning of a superclass''s implementation of the method')
		(messageCategory	'Which method category the method lies in')
		(sendersCount		'A report of how many senders there of the message.')
		(implementorsCount	'A report of how many implementors there are of the message.')
		(recentChangeSet	'The most recent change set bearing the method.')
		(allChangeSets		'A list of all change sets bearing the method.')
		(priorVersionsCount	'A report of how many previous versions there are of the method' )
		(priorTimeStamp		'The time stamp of the penultimate submission of the method, if any'))! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 13:13'!
annotationPanes
	^ CodeHolder showAnnotationPane! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:00'!
annotationPanesSetting
	^ CodeHolder showAnnotationPane! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:41'!
annotationPanesSetting: aBoolean
	
	CodeHolder showAnnotationPane: aBoolean.
	MCCodeTool showAnnotationPane: aBoolean.! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 07:34'!
areaFillsAreTolerant
	^ self areaFillsAreTolerantSetting! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/11/2009 07:34'!
areaFillsAreTolerantSetting
	^ Form floodFillTolerance > 0.0! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/11/2009 07:34'!
areaFillsAreTolerantSetting: aBoolean 
	Form
		floodFillTolerance: (aBoolean
				ifTrue: [0.1]
				ifFalse: [0.0])! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 07:36'!
areaFillsAreVeryTolerant
	^ self areaFillsAreVeryTolerantSetting
! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/11/2009 07:35'!
areaFillsAreVeryTolerantSetting
	^ Form floodFillTolerance > 0.1! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/11/2009 07:35'!
areaFillsAreVeryTolerantSetting: aBoolean 
	Form
		floodFillTolerance: (aBoolean
				ifTrue: [0.2]
				ifFalse: [0.1])! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
autoFocusForColumns
	^ self
		valueOfFlag: #autoFocusForColumns
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
autoIndent
	^ self
		valueOfFlag: #autoIndent
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
automaticKeyGeneration
	^ self
		valueOfFlag: #automaticKeyGeneration
		ifAbsent: [false]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
automaticPlatformSettings
	^ self
		valueOfFlag: #automaticPlatformSettings
		ifAbsent: [true]! !

!Preferences class methodsFor: 'misc' stamp: 'AlainPlantec 1/7/2010 23:39'!
balloonHelpDelayTime
	"Answer the number of milliseconds before a balloon help 
	should be put up on morphs."
	^ self parameters
		at: #balloonHelpDelayTime
		ifAbsent: [800]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/10/2009 10:23'!
balloonHelpEnabled
	^ self balloonHelpEnabledSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/21/2009 12:12'!
balloonHelpEnabledSetting
	^ UITheme currentSettings balloonHelpEnabled! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/19/2009 23:21'!
balloonHelpEnabledSetting: aBoolean
	^ UITheme currentSettings balloonHelpEnabled: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
beDynamic
	^ self
		valueOfFlag: #beDynamic
		ifAbsent: [false]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
biggerHandles
	^ self
		valueOfFlag: #biggerHandles
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 15:04'!
browseWithPrettyPrint
	^ CodeHolder browseWithPrettyPrint 
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:00'!
browseWithPrettyPrintSetting
	^ CodeHolder browseWithPrettyPrint
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:42'!
browseWithPrettyPrintSetting: aBoolean
	CodeHolder browseWithPrettyPrint: aBoolean
! !

!Preferences class methodsFor: 'text highlighting' stamp: 'AlainPlantec 1/7/2010 23:39'!
caretWidth
	^ self parameters at: #caretWidth! !

!Preferences class methodsFor: 'text highlighting' stamp: 'AlainPlantec 1/7/2010 23:39'!
caretWidth: anInteger
	^ self parameters at: #caretWidth put: anInteger! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/10/2009 23:05'!
caseSensitiveFinds
	^ self caseSensitiveFindsSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 22:57'!
caseSensitiveFindsSetting
	^ ParagraphEditor caseSensitiveFinds! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 22:58'!
caseSensitiveFindsSetting: aBoolean
	ParagraphEditor caseSensitiveFinds: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
chasingBrowsers
	^ self
		valueOfFlag: #chasingBrowsers
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 10:58'!
checkForSlips
	^ ChangeSet mustCheckForSlips! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:18'!
checkForSlipsSetting
	^ ChangeSet mustCheckForSlips! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:18'!
checkForSlipsSetting: aBoolean
	ChangeSet mustCheckForSlips: aBoolean! !

!Preferences class methodsFor: 'window colors' stamp: 'AlainPlantec 12/16/2009 21:25'!
checkForWindowColors
	self deprecated: 'Not used anymore since Settings integration'! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 15:15'!
chooseBalloonHelpFont
	BalloonMorph chooseBalloonFont! !

!Preferences class methodsFor: 'FreeType-override' stamp: 'AlainPlantec 12/6/2009 15:14'!
chooseCodeFont
	"Not currently sent, but once protocols are sorted out so that we can disriminate on whether a text object being launched is for code or not, will be reincorporated"

	self 
		chooseFontWithPrompt: 'Code font...' translated 
		andSendTo: StandardFonts 
		withSelector: #codeFont: 
		highlightSelector: #codeFont.! !

!Preferences class methodsFor: 'fonts' stamp: 'laza 3/25/2004 23:11'!
chooseFontWithPrompt: aPrompt andSendTo: aReceiver withSelector: aSelector
	self chooseFontWithPrompt: aPrompt andSendTo: aReceiver withSelector: aSelector highlight: nil
! !

!Preferences class methodsFor: 'fonts' stamp: 'alain.plantec 5/30/2008 14:18'!
chooseFontWithPrompt: aPrompt andSendTo: aReceiver withSelector: aSelector highlight: currentFont
	TextStyle promptForFont: aPrompt andSendTo: aReceiver withSelector: aSelector highlight: currentFont! !

!Preferences class methodsFor: 'FreeType-addition' stamp: 'marcus.denker 11/27/2008 16:16'!
chooseFontWithPrompt: aPrompt andSendTo: aReceiver withSelector: aSelector highlightSelector: highlightSelector

	FontChooser openWithWindowTitle: aPrompt 
				for: aReceiver 
				setSelector: aSelector
				getSelector: highlightSelector
	! !

!Preferences class methodsFor: 'FreeType-override' stamp: 'AlainPlantec 12/6/2009 15:16'!
chooseHaloLabelFont
	"present a menu with the possible fonts for label in halo"
	self
		chooseFontWithPrompt: 'Halo Label font...'
		andSendTo: StandardFonts
		withSelector: #haloFont:
		highlightSelector: #haloFont! !

!Preferences class methodsFor: 'initialization' stamp: 'StephaneDucasse 11/6/2009 20:03'!
chooseInitialSettings
	"Restore the default choices for all of the standard Preferences."

	self allPreferenceObjects do:
		[:aPreference |
			aPreference restoreDefaultValue].
	! !

!Preferences class methodsFor: 'FreeType-override' stamp: 'AlainPlantec 12/6/2009 15:17'!
chooseListFont
	self 
		chooseFontWithPrompt: 'List font...' translated
		andSendTo: StandardFonts 
		withSelector: #listFont: 
		highlightSelector: #listFont! !

!Preferences class methodsFor: 'FreeType-override' stamp: 'AlainPlantec 12/6/2009 15:18'!
chooseMenuFont
	self 
		chooseFontWithPrompt: 'Menu font...' translated
		andSendTo: StandardFonts 
		withSelector: #menuFont: 
		highlightSelector: #menuFont! !

!Preferences class methodsFor: 'FreeType-override' stamp: 'AlainPlantec 12/6/2009 15:18'!
chooseStandardButtonFont
	self 
		chooseFontWithPrompt: 'Button font...' translated
		andSendTo: StandardFonts 
		withSelector: #buttonFont: 
		highlightSelector: #buttonFont

! !

!Preferences class methodsFor: 'FreeType-override' stamp: 'AlainPlantec 12/6/2009 15:19'!
chooseSystemFont
	self 
		chooseFontWithPrompt: 'Default font...' translated
		andSendTo: StandardFonts 
		withSelector: #defaultFont:
		highlightSelector: #defaultFont! !

!Preferences class methodsFor: 'FreeType-override' stamp: 'AlainPlantec 12/6/2009 15:19'!
chooseWindowTitleFont
	self 
		chooseFontWithPrompt: 'Window Title font...' translated
		andSendTo: StandardFonts 
		withSelector: #windowTitleFont: 
		highlightSelector: #windowTitleFont! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
classCommentOnClassSelect
	^ self
		valueOfFlag: #classCommentOnClassSelect
		ifAbsent: [false]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 11:46'!
cmdDotEnabled
	^UserInterruptHandler cmdDotEnabled
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:08'!
cmdDotEnabledSetting
	^UserInterruptHandler cmdDotEnabled
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:08'!
cmdDotEnabledSetting: aBoolean
	UserInterruptHandler cmdDotEnabled: aBoolean
! !

!Preferences class methodsFor: 'standard queries' stamp: 'programmatic 7/15/1999 09:55'!
cmdGesturesEnabled
	"compiled programatically -- return hard-coded preference value"
	^ true! !

!Preferences class methodsFor: 'hard-coded prefs' stamp: 'programmatic 7/15/1999 09:55'!
cmdKeysInText
	"compiled programatically -- return hard-coded preference value"
	^ true! !

!Preferences class methodsFor: 'initialization' stamp: 'NS 1/28/2004 14:43'!
compileAccessMethodForPreference: aPreference
	"Compile an accessor method for the given preference"

	self class compileSilently: (aPreference name, '
	^ self valueOfFlag: #', aPreference name, ' ifAbsent: [', aPreference defaultValue storeString, ']') classified: 'standard queries'! !

!Preferences class methodsFor: 'personalization' stamp: 'NS 1/28/2004 14:43'!
compileHardCodedPref: prefName enable: aBoolean
	"Compile a method that returns a simple true or false (depending on the value of aBoolean) when Preferences is sent prefName as a message"

	self class compileSilently: (prefName asString, '
	"compiled programatically -- return hard-coded preference value"
	^ ', aBoolean storeString) classified: 'hard-coded prefs'.
	
"Preferences compileHardCodedPref: #testing enable: false"! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 11:46'!
cpuWatcherEnabled
	^ CPUWatcher cpuWatcherEnabled
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:08'!
cpuWatcherEnabledSetting
	^ CPUWatcher cpuWatcherEnabled
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:08'!
cpuWatcherEnabledSetting: aBoolean
	CPUWatcher cpuWatcherEnabled: aBoolean
! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/6/2009 21:16'!
debugHaloHandle
	^ HaloMorph haloWithDebugHandle! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/8/2009 11:09'!
debugHaloHandleSetting
	^ HaloMorph haloWithDebugHandle! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/8/2009 11:09'!
debugHaloHandleSetting: aBoolean
	HaloMorph haloWithDebugHandle: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/18/2009 17:04'!
debugLogTimestamp
	^ Debugger debugLogTimestamp! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/6/2009 21:21'!
debugPrintSpaceLog
	^ ImageSegment debugPrintSpaceLog! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:09'!
debugPrintSpaceLogSetting
	^ ImageSegment debugPrintSpaceLog! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:10'!
debugPrintSpaceLogSetting: aBoolean
	ImageSegment debugPrintSpaceLog: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/6/2009 21:43'!
debugShowDamage
	^ WorldState debugShowDamage
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:10'!
debugShowDamageSetting
	^ WorldState debugShowDamage
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:10'!
debugShowDamageSetting: aBoolean
	 WorldState debugShowDamage: aBoolean
! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/8/2009 10:43'!
decorateBrowserButtons
	^ CodeHolder decorateBrowserButtons! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:01'!
decorateBrowserButtonsSetting
	^ CodeHolder decorateBrowserButtons! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:44'!
decorateBrowserButtonsSetting: aBoolean
	CodeHolder decorateBrowserButtons: aBoolean! !

!Preferences class methodsFor: 'parameters' stamp: 'AlainPlantec 1/7/2010 23:40'!
defaultAnnotationRequests
	^ self parameters at: #MethodAnnotations ifAbsent:
		[self setDefaultAnnotationInfo]
	"Preferences annotationInfo"! !

!Preferences class methodsFor: 'parameters' stamp: 'AlainPlantec 1/7/2010 23:40'!
defaultAnnotationRequests: newList
	^ self parameters at: #MethodAnnotations put: newList! !

!Preferences class methodsFor: 'parameters' stamp: 'on 5/10/2008 15:10'!
defaultAuthorName
	"Answer the author name to be planted, by default, in a changeset-preamble template.  You can hard-code this to hold your name, thus saving you time when writing the preambles of subsequent changesets"

	^ Author fullName! !

!Preferences class methodsFor: 'parameters' stamp: 'sw 2/1/2000 14:05'!
defaultPaintingExtent
	"Answer the preferred size for the onion-skin paint area when launching a new painting within a paste-up morph.  Feel free to change the parameters to suit your configuration."

	^ 800 @ 600! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
defaultWindowColor
	^ self
		valueOfFlag: #defaultWindowColor
		ifAbsent: [Color
				r: 1.0
				g: 1.0
				b: 1.0]! !

!Preferences class methodsFor: 'menu parameters' stamp: 'AlainPlantec 12/7/2009 15:04'!
defaultWorldColor
	^ PasteUpMorph  defaultWorldColor ! !

!Preferences class methodsFor: 'parameters' stamp: 'AlainPlantec 1/10/2010 07:42'!
desktopColor
	^ PolymorphSystemSettings desktopColor 
! !

!Preferences class methodsFor: 'parameters' stamp: 'AlainPlantec 1/10/2010 07:42'!
desktopColor: aColor
	"Record a new desktop color preference."
	PolymorphSystemSettings desktopColor: aColor.
! !

!Preferences class methodsFor: 'accessing' stamp: 'AlainPlantec 1/7/2010 23:26'!
dictionaryOfPreferences
	^DictionaryOfPreferences ifNil: [DictionaryOfPreferences := IdentityDictionary new]! !

!Preferences class methodsFor: 'accessing' stamp: 'rr 10/1/2005 15:14'!
dictionaryOfPreferences: anObject
	DictionaryOfPreferences := anObject! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/8/2009 10:45'!
diffsInChangeList
	^ CodeHolder diffsInChangeList! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:01'!
diffsInChangeListSetting
	^ CodeHolder diffsInChangeList! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:45'!
diffsInChangeListSetting: aBoolean
	^ CodeHolder diffsInChangeList: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/8/2009 10:45'!
diffsWithPrettyPrint
	^ CodeHolder diffsWithPrettyPrint! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:01'!
diffsWithPrettyPrintSetting
	^ CodeHolder diffsWithPrettyPrint! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:46'!
diffsWithPrettyPrintSetting: aBoolean
	CodeHolder diffsWithPrettyPrint: aBoolean! !

!Preferences class methodsFor: 'get/set' stamp: 'AlainPlantec 12/8/2009 10:19'!
disable: aSymbol
	"Shorthand access to enabling a preference of the given name.  If there is none in the image, conjure one up"

	| aPreference |
	aPreference := self preferenceAt: aSymbol ifAbsent:
		[self addPreference: aSymbol category: 'unclassified' default: false balloonHelp: 'this preference was added idiosyncratically and has no help message.'.
		self preferenceAt: aSymbol].
	aPreference preferenceValue: false! !

!Preferences class methodsFor: 'Polymorph-Widgets-Override' stamp: 'StephaneDucasse 3/17/2010 21:16'!
disableProgrammerFacilities
	"Warning: do not call this lightly!!  It disables all access to menus, debuggers, halos.  There is no guaranteed return from this, which is to say, you cannot necessarily reenable these things once they are disabled -- you can only use whatever the UI of the current project affords, and you cannot even snapshot -- you can only quit. 

     You can completely reverse the work of this method by calling the dual Preferences method enableProgrammerFacilities, provided you have left yourself leeway to bring about a call to that method.
(does not reverse the ToolSet registrations)

	To set up a system that will come up in such a state, you have to request the snapshot in the same breath as you disable the programmer facilities.  To do this, put the following line into the 'do' menu and then evaluate it from that 'do' menu:

         Preferences disableProgrammerFacilities.

You will be prompted for a new image name under which to save the resulting image."
	self deprecated: 'No replacement for now'.

	Beeper beep.
	(self 
		confirm: 'CAUTION!!!!
This is a drastic step!!
Do you really want to do this?') 
			ifFalse: 
				[Beeper beep.
				^self inform: 'whew!!'].
	self disable: #cmdDotEnabled.	"No user-interrupt-into-debugger"
	self disable: #editableStringMorphs. "turn off shift-click editing"
	ToolSet registeredClasses copy do: [:c | ToolSet unregister: c].
	ToolSet default: nil. "unregister and make sure default is nil to really prevent debug windows"
		"also now takes care of low space watcher interrupts"
	self compileHardCodedPref: #cmdGesturesEnabled enable: false.	"No halos, etc."
	self compileHardCodedPref: #cmdKeysInText enable: false.	"No user commands invokable via cmd-key combos in text editor"
	self enable: #noviceMode.	"No control-menu"
	self disable: #warnIfNoSourcesFile.
	self disable: #warnIfNoChangesFile.
	Smalltalk saveAs! !

!Preferences class methodsFor: 'Polymorph-Widgets' stamp: 'AlainPlantec 12/5/2009 18:57'!
disableProgrammerFacilitiesWithoutWarning
	"Warning: do not call this lightly!!  It disables all access to menus, debuggers, halos.  There is no guaranteed return from this, which is to say, you cannot necessarily reenable these things once they are disabled -- you can only use whatever the UI of the current project affords, and you cannot even snapshot -- you can only quit."
	self deprecated: 'No replacement for now'.

	self disable: #cmdDotEnabled.	"No user-interrupt-into-debugger"
	self disable: #editableStringMorphs. "turn off shift-click editing"
	ToolSet registeredClasses copy do: [:c | ToolSet unregister: c].
	ToolSet default: nil. "unregister and make sure default is nil to really prevent debug windows"
		"also now takes care of low space watcher interrupts"
	self compileHardCodedPref: #cmdGesturesEnabled enable: false.	"No halos, etc."
	self compileHardCodedPref: #cmdKeysInText enable: false.	"No user commands invokable via cmd-key combos in text editor"
	self enable: #noviceMode.	"No control-menu"
	self disable: #warnIfNoSourcesFile.
	self disable: #warnIfNoChangesFile! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
dismissAllOnOptionClose
	^ self
		valueOfFlag: #dismissAllOnOptionClose
		ifAbsent: [false]! !

!Preferences class methodsFor: 'get/set' stamp: 'sw 11/11/1998 11:40'!
doesNotUnderstand: aMessage
	"Look up the message selector as a flag."
	aMessage arguments size > 0 ifTrue: [^ super doesNotUnderstand: aMessage].
	^ self valueOfFlag: aMessage selector
! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
dualChangeSorterWindowColor
	^ self
		valueOfFlag: #dualChangeSorterWindowColor
		ifAbsent: [Color
				r: 0.8
				g: 1.0
				b: 1.0]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/17/2009 10:00'!
duplicateAllControlAndAltKeys
	^ self duplicateAllControlAndAltKeysSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/17/2009 09:57'!
duplicateAllControlAndAltKeysSetting
	^ InputEventSensor controlAltKeyDecodePolicy = #FullMatching! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/17/2009 10:05'!
duplicateAllControlAndAltKeysSetting: aBoolean
	aBoolean ifTrue: [InputEventSensor controlAltKeyDecodePolicy: #FullMatching]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/17/2009 10:00'!
duplicateControlAndAltKeys
	^ self duplicateControlAndAltKeysSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/17/2009 09:58'!
duplicateControlAndAltKeysSetting
	^ InputEventSensor controlAltKeyDecodePolicy = #PartialMatching
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/17/2009 10:05'!
duplicateControlAndAltKeysSetting: aBoolean
	aBoolean ifTrue: [InputEventSensor controlAltKeyDecodePolicy: #PartialMatching]
! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
dynamicProtocolActivation
	^ self
		valueOfFlag: #dynamicProtocolActivation
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 08:16'!
easySelection
	^ self easySelectionSetting
! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/11/2009 08:16'!
easySelectionSetting
	^ WorldState easySelectingWorld! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/11/2009 08:16'!
easySelectionSetting: aBoolean 
	WorldState easySelectingWorld: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
ecompletionCaseSensitive
	^ self
		valueOfFlag: #ecompletionCaseSensitive
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
ecompletionEnabled
	^ self
		valueOfFlag: #ecompletionEnabled
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
ecompletionSmartCharacters
	^ self
		valueOfFlag: #ecompletionSmartCharacters
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/10/2009 11:51'!
editableStringMorphs
	^ self editableStringMorphsSetting
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 11:50'!
editableStringMorphsSetting
	^ StringMorph editableStringMorph! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 11:51'!
editableStringMorphsSetting: aBoolean
	StringMorph editableStringMorph: aBoolean! !

!Preferences class methodsFor: 'get/set' stamp: 'AlainPlantec 12/8/2009 10:17'!
enable: aSymbol
	"Shorthand access to enabling a preference of the given name.  If there is none in the image, conjure one up"

	| aPreference |
	aPreference := self preferenceAt: aSymbol ifAbsent:
		[self addPreference: aSymbol category: 'unclassified' default: true balloonHelp: 'this preference was added idiosyncratically and has no help message.'.
		self preferenceAt: aSymbol].
	aPreference preferenceValue: true! !

!Preferences class methodsFor: 'Polymorph-Widgets-Override' stamp: 'AlainPlantec 12/5/2009 18:56'!
enableProgrammerFacilities
	"Meant as a one-touch recovery from a #disableProgrammerFacilities call."
	"Preferences enableProgrammerFacilities"
	self deprecated: 'No replacement for now'.
	self enable: #editableStringMorphs.
	self enable: #cmdDotEnabled.
	self compileHardCodedPref: #cmdGesturesEnabled enable: true. 
	self compileHardCodedPref: #cmdKeysInText enable: true.
	self disable: #noviceMode.
	self enable: #warnIfNoSourcesFile.
	self enable: #warnIfNoChangesFile.
	ToolSet default: StandardToolSet ! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
externalFocusForPluggableText
	^ self
		valueOfFlag: #externalFocusForPluggableText
		ifAbsent: [true]! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/11/2009 08:17'!
externalFocusForPluggableTextSetting
	^ TextMorph externalFocusIndication! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/11/2009 08:17'!
externalFocusForPluggableTextSetting: aBoolean 
	TextMorph externalFocusIndication: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/6/2009 21:50'!
extraDebuggerButtons
	^ Debugger extraDebuggerButtons! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:10'!
extraDebuggerButtonsSetting
	^ Debugger extraDebuggerButtons! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:10'!
extraDebuggerButtonsSetting: aBoolean
	Debugger extraDebuggerButtons: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
fadedBackgroundWindows
	^ self
		valueOfFlag: #fadedBackgroundWindows
		ifAbsent: [true]! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/14/2009 14:31'!
fadedBackgroundWindowsSetting
	^ UITheme currentSettings fadedBackgroundWindows! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/14/2009 14:31'!
fadedBackgroundWindowsSetting: aBoolean
	^ UITheme currentSettings fadedBackgroundWindows: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/14/2009 21:37'!
fastDragWindowForMorphic
	^ self fastDragWindowForMorphicSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/14/2009 21:37'!
fastDragWindowForMorphicSetting
	^ UITheme currentSettings fastDragging! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/14/2009 21:37'!
fastDragWindowForMorphicSetting: aBoolean
	UITheme currentSettings fastDragging: aBoolean! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:54'!
fontConfigurationMenu
	| aMenu |

	aMenu := MenuMorph new defaultTarget: Preferences.
	aMenu addTitle: 'Standard System Fonts' translated.
	
	aMenu addStayUpIcons.
	
	aMenu add: 'default text font...' translated action: #chooseSystemFont.
	aMenu balloonTextForLastItem: 'Choose the default font to be used for code and  in workspaces, transcripts, etc.' translated.
	aMenu lastItem font: StandardFonts defaultFont.
	
	aMenu add: 'list font...' translated action: #chooseListFont.
	aMenu lastItem font: Preferences standardListFont.
	aMenu balloonTextForLastItem: 'Choose the font to be used in list panes' translated.
	
	aMenu add: 'halo label font...' translated action: #chooseHaloLabelFont.
	aMenu lastItem font: Preferences standardHaloLabelFont.
	aMenu balloonTextForLastItem: 'Choose the font to be used on labels ih halo' translated.

	aMenu add: 'menu font...' translated action: #chooseMenuFont.
	aMenu lastItem font: Preferences standardMenuFont.
	aMenu balloonTextForLastItem: 'Choose the font to be used in menus' translated.
	
	aMenu add: 'window-title font...' translated action: #chooseWindowTitleFont.
	aMenu lastItem font: Preferences windowTitleFont.
	aMenu balloonTextForLastItem: 'Choose the font to be used in window titles.' translated.

	aMenu add: 'balloon-help font...' translated action: #chooseBalloonHelpFont.
	aMenu lastItem font: Preferences standardBalloonHelpFont.
	aMenu balloonTextForLastItem: 'choose the font to be used when presenting balloon help.' translated.
	
	aMenu add: 'code font...' translated action: #chooseCodeFont. 
	aMenu lastItem font: Preferences standardCodeFont. 
	aMenu balloonTextForLastItem: 'Choose the font to be used in code panes.' translated.

	aMenu add: 'button font...' translated action: #chooseStandardButtonFont.
	aMenu lastItem font: Preferences standardButtonFont.
	aMenu balloonTextForLastItem: 'Choose the font to be used in buttons.' translated.

	aMenu addLine.
	aMenu add: 'demo mode' translated action: #setDemoFonts.
	aMenu balloonTextForLastItem: 'Set Fonts usable for giving a presentation' translated.

	aMenu addLine.
	aMenu add: 'restore default font choices' translated action: #restoreDefaultFonts.
	aMenu balloonTextForLastItem: 'Use the standard system font defaults' translated.
	
	aMenu add: 'print default font choices' translated action: #printStandardSystemFonts.
	aMenu balloonTextForLastItem: 'Print the standard system font defaults to the Transcript' translated.

	^ aMenu! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/14/2009 18:47'!
fullScreenLeavesDeskMargins
	^ self fullScreenLeavesDeskMarginsSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/14/2009 18:46'!
fullScreenLeavesDeskMarginsSetting
	^ SystemWindow fullScreenMargin > 0! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/14/2009 18:49'!
fullScreenLeavesDeskMarginsSetting: aBoolean 
	^ SystemWindow fullScreenMargin: (aBoolean	ifFalse: [0])! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/10/2009 13:06'!
generalizedYellowButtonMenu
	^ self generalizedYellowButtonMenuSetting
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 13:05'!
generalizedYellowButtonMenuSetting
	^ Morph defaultYellowButtonMenuEnabled! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 13:06'!
generalizedYellowButtonMenuSetting: aBoolean
	Morph defaultYellowButtonMenuEnabled: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
gradientButtonLook
	^ self
		valueOfFlag: #gradientButtonLook
		ifAbsent: [true]! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/13/2009 13:25'!
gradientButtonLookSetting
	^ UITheme currentSettings preferGradientFill ! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/13/2009 13:25'!
gradientButtonLookSetting: aBoolean 
	UITheme currentSettings preferGradientFill: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/13/2009 21:51'!
gradientMenu
	^ self  gradientMenuSetting
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/13/2009 13:12'!
gradientMenuSetting
	^ UITheme current settings preferGradientFill ! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/13/2009 21:52'!
gradientMenuSetting: aBoolean
	^ UITheme currentSettings preferGradientFill: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 23:10'!
haloEnclosesFullBounds
	^ self haloEnclosesFullBoundsSetting
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 23:10'!
haloEnclosesFullBoundsSetting
	^ HaloMorph haloEnclosesFullBounds
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 23:10'!
haloEnclosesFullBoundsSetting: aBoolean
	HaloMorph haloEnclosesFullBounds: aBoolean
! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: ''!
haloTheme
	^ self
		valueOfFlag: #haloTheme
		ifAbsent: [#iconicHaloSpecifications]! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/12/2009 10:07'!
haloThemeSetting
	^ #iconicHaloSpecifications! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
haloTransitions
	^ self
		valueOfFlag: #haloTransitions
		ifAbsent: [false]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
hierarchyBrowserIsRB
	^ self
		valueOfFlag: #hierarchyBrowserIsRB
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 15:06'!
httpProxyPort
	^ HTTPSocket httpProxyPort 
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:25'!
httpProxyPortSetting
	^ HTTPSocket httpProxyPort 
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:25'!
httpProxyPortSetting: aPort
	HTTPSocket httpProxyPort: aPort
! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 15:06'!
httpProxyServer
	^ HTTPSocket httpProxyServer 
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:26'!
httpProxyServerSetting
	^ HTTPSocket httpProxyServer 
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:26'!
httpProxyServerSetting: aServerName
	HTTPSocket httpProxyServer: aServerName
! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 08:46'!
infiniteUndo
	^ self infiniteUndoSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 08:44'!
infiniteUndoSetting
	^ CommandHistory infiniteUndo! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 08:46'!
infiniteUndoSetting: aBoolean
	CommandHistory infiniteUndo: aBoolean! !

!Preferences class methodsFor: 'initialization' stamp: 'rr 10/1/2005 15:14'!
initializeDictionaryOfPreferences
	"Initialize the DictionaryOfPreferences to be an empty IdentityDictionary"

	"Preferences initializeDictionaryOfPreferences"

	self  dictionaryOfPreferences:IdentityDictionary new! !

!Preferences class methodsFor: 'parameters' stamp: 'sw 9/7/1999 12:45'!
initializeParameters
	"Preferences initializeParameters"
	Parameters := IdentityDictionary new.
	self restoreDefaultMenuParameters.
	Parameters at: #maxBalloonHelpLineLength put: 28.
	self initializeTextHighlightingParameters! !

!Preferences class methodsFor: 'text highlighting' stamp: 'lr 7/12/2006 09:42'!
initializeTextHighlightingParameters
	"Preferences initializeTextHighlightingParameters"

	self
		caretWidth: 2;
		insertionPointColor: (TranslucentColor r: 0.0 g: 0.0 b: 0.8 alpha: 0.8);
		textHighlightColor: (TranslucentColor r: 0.0 g: 0.0 b: 0.8 alpha: 0.2)! !

!Preferences class methodsFor: 'text highlighting' stamp: 'AlainPlantec 1/7/2010 23:41'!
insertionPointColor
	^ self parameters at: #insertionPointColor! !

!Preferences class methodsFor: 'text highlighting' stamp: 'AlainPlantec 1/7/2010 23:41'!
insertionPointColor: aColor
	self parameters at: #insertionPointColor put: aColor! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/14/2009 19:17'!
keepTasklistOpen
	^ self keepTasklistOpenSetting
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/14/2009 19:16'!
keepTasklistOpenSetting
	^ TasklistMorph keepOpen! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/14/2009 19:16'!
keepTasklistOpenSetting: aBoolean
	^ TasklistMorph keepOpen: aBoolean! !

!Preferences class methodsFor: 'text highlighting' stamp: 'AlainPlantec 1/7/2010 23:41'!
keyboardFocusColor
	"Answer the keyboard focus color, initializing it if necessary"

	^ self parameters at: #keyboardFocusColor ifAbsentPut: [Color lightGray]

"
Parameters removeKey: #keyboardFocusColor.
Preferences keyboardFocusColor
"! !

!Preferences class methodsFor: 'initialization' stamp: 'StephaneDucasse 2/19/2010 17:27'!
localeChanged
	! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/6/2009 21:59'!
logDebuggerStackToFile
	^ Debugger logDebuggerStackToFile
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:11'!
logDebuggerStackToFileSetting
	^ Debugger logDebuggerStackToFile
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:11'!
logDebuggerStackToFileSetting: aBoolean
	Debugger logDebuggerStackToFile: aBoolean
! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
magicHalos
	^ self
		valueOfFlag: #magicHalos
		ifAbsent: [false
			"Form literalScannedAs: 14 notifying: nil 14
			Form literalScannedAs: #OneBitForm notiEfying: nil OneBitForm
			Form literalScannedAs: ##OneBitForm notifying: nil
			OneBitForm->a Form
			Form literalScannedAs: ##Form notifying: nil Form->Form
			Form literalScannedAs: ###Form notifying: nil nilE->Form clas
			"]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
maintainHalos
	^ self
		valueOfFlag: #maintainHalos
		ifAbsent: [true]! !

!Preferences class methodsFor: 'parameters' stamp: 'AlainPlantec 1/7/2010 23:41'!
maxBalloonHelpLineLength
	^ self parameters at: #maxBalloonHelpLineLength! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/13/2009 20:03'!
menuAppearance3d
	^ self menuAppearance3dSetting ! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/13/2009 20:00'!
menuAppearance3dSetting
	^ UITheme currentSettings flatMenu not! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/13/2009 20:00'!
menuAppearance3dSetting: aBoolean
	^ UITheme currentSettings flatMenu: aBoolean not! !

!Preferences class methodsFor: 'menu parameters' stamp: 'AlainPlantec 1/7/2010 23:42'!
menuBorderColor
	Display depth <= 2 ifTrue: [^ Color black].
	^ self parameters at: #menuBorderColor! !

!Preferences class methodsFor: 'menu parameters' stamp: 'AlainPlantec 1/7/2010 23:42'!
menuBorderWidth
	^ self parameters at: #menuBorderWidth! !

!Preferences class methodsFor: 'menu parameters' stamp: 'AlainPlantec 1/7/2010 23:42'!
menuColor
	Display depth <= 2 ifTrue: [^ Color white].
	^ self parameters at: #menuColor! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/13/2009 18:31'!
menuColorFromWorld
	^ self menuColorFromWorldSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/13/2009 18:25'!
menuColorFromWorldSetting
	^ UITheme currentSettings autoMenuColor! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/13/2009 18:24'!
menuColorFromWorldSetting: aBoolean
	UITheme currentSettings autoMenuColor: aBoolean! !

!Preferences class methodsFor: 'settings-no-migration' stamp: 'AlainPlantec 12/19/2009 23:23'!
menuKeyboardControl
	^ UITheme currentSettings menuKeyboardControl! !

!Preferences class methodsFor: 'menu parameters' stamp: 'AlainPlantec 1/7/2010 23:42'!
menuLineColor
	^ self parameters
		at: #menuLineColor
		ifAbsentPut: [Preferences menuBorderColor lighter]! !

!Preferences class methodsFor: 'menu parameters' stamp: 'AlainPlantec 12/19/2009 14:07'!
menuSelectionColor
	^ UITheme currentSettings menuSelectionColor! !

!Preferences class methodsFor: 'menu parameters' stamp: 'AlainPlantec 1/7/2010 23:42'!
menuTitleBorderColor
	Display depth <= 2 ifTrue: [^ Color black].
	^ self parameters at: #menuTitleBorderColor! !

!Preferences class methodsFor: 'menu parameters' stamp: 'AlainPlantec 1/7/2010 23:42'!
menuTitleBorderWidth
	^ self parameters at: #menuTitleBorderWidth! !

!Preferences class methodsFor: 'menu parameters' stamp: 'AlainPlantec 1/7/2010 23:42'!
menuTitleColor
	Display depth = 1 ifTrue: [^ Color white].
	Display depth = 2 ifTrue: [^ Color gray].
	^ self parameters at: #menuTitleColor! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/13/2009 15:27'!
menuWithIcons
	^ self menuWithIconsSetting
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/13/2009 15:26'!
menuWithIconsSetting
	^ UITheme currentSettings menuWithIcons! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/13/2009 15:26'!
menuWithIconsSetting: aBoolean
	^ UITheme currentSettings menuWithIcons: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
mercuryPanel
	^ self
		valueOfFlag: #mercuryPanel
		ifAbsent: [false]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
messageListWindowColor
	^ self
		valueOfFlag: #messageListWindowColor
		ifAbsent: [Color
				r: 0.8
				g: 1.0
				b: 1.0]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
messageNamesWindowColor
	^ self
		valueOfFlag: #messageNamesWindowColor
		ifAbsent: [Color
				r: 0.645
				g: 1.0
				b: 0.452]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
methodFinderWindowColor
	^ self
		valueOfFlag: #methodFinderWindowColor
		ifAbsent: [Color
				r: 0.4
				g: 1.0
				b: 1.0]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
modalColorPickers
	^ self
		valueOfFlag: #modalColorPickers
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
mouseClickForKeyboardFocus
	^ self
		valueOfFlag: #mouseClickForKeyboardFocus
		ifAbsent: [false]! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 14:31'!
mouseClickForKeyboardFocusSetting
	^ MorphicModel keyboardFocusOnMouseDown! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 14:31'!
mouseClickForKeyboardFocusSetting: aBoolean
	MorphicModel keyboardFocusOnMouseDown: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/10/2009 14:54'!
mouseOverForKeyboardFocus
	^ self mouseOverForKeyboardFocusSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 14:54'!
mouseOverForKeyboardFocusSetting
	^ MorphicModel mouseOverForKeyboardFocus! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 14:54'!
mouseOverForKeyboardFocusSetting: aBoolean
	MorphicModel mouseOverForKeyboardFocus: aBoolean! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
mouseOverHalos
	^ self
		valueOfFlag: #mouseOverHalos
		ifAbsent: [false]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 09:33'!
multipleTextUndo
	^ self multipleTextUndoSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 09:33'!
multipleTextUndoSetting
	^ TextMorphEditor useMultipleUndo! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 09:34'!
multipleTextUndoSetting: aBoolean
	TextMorphEditor useMultipleUndo: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
noWindowAnimationForClosing
	^ self
		valueOfFlag: #noWindowAnimationForClosing
		ifAbsent: [false]! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/15/2009 10:50'!
noWindowAnimationForClosingSetting
	^ UITheme currentAnimationSettings animateClosing not! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/15/2009 10:50'!
noWindowAnimationForClosingSetting: aBoolean
	UITheme currentAnimationSettings animateClosing: aBoolean not! !

!Preferences class methodsFor: 'misc' stamp: 'sw 4/24/2001 12:02'!
okayToChangeProjectLocalnessOf: prefSymbol
	"Answer whether it would be okay to allow the user to switch the setting of whether or not the preference symbol is local to a project.  Formerly useful and perhaps again will be, though to be sure this is a non-modular design."

	^ (#() includes: prefSymbol) not! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 13:12'!
optionalButtons
	^ CodeHolder optionalButtons! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:01'!
optionalButtonsSetting
	^ CodeHolder optionalButtons! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:47'!
optionalButtonsSetting: aBoolean
	CodeHolder optionalButtons: aBoolean! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
packageBrowserWindowColor
	^ self
		valueOfFlag: #packageBrowserWindowColor
		ifAbsent: [Color
				r: 1.0
				g: 1.0
				b: 0.6]! !

!Preferences class methodsFor: 'parameters' stamp: 'AlainPlantec 1/7/2010 23:42'!
parameterAt: aKey
	^ self parameters at: aKey ifAbsent: [nil]! !

!Preferences class methodsFor: 'parameters' stamp: 'sw 9/28/2001 08:52'!
parameterAt: aKey default: defaultValueBlock
	"Deprecated interface; no surviving senders in the released image, but clients probably still use"

	^ self parameterAt: aKey ifAbsentPut: defaultValueBlock! !

!Preferences class methodsFor: 'parameters' stamp: 'AlainPlantec 1/7/2010 23:42'!
parameterAt: aKey ifAbsent: aBlock
	"Answer the parameter saved at the given key; if there is no such key in the Parameters dictionary, evaluate aBlock"

	^ self parameters at: aKey ifAbsent: [aBlock value]! !

!Preferences class methodsFor: 'parameters' stamp: 'AlainPlantec 1/7/2010 23:42'!
parameterAt: aKey ifAbsentPut: defaultValueBlock
	"Return the Parameter setting at the given key.  If there is no entry for this key in the Parameters dictionary, create one with the value of defaultValueBlock as its value"

	^ self parameters at: aKey ifAbsentPut: defaultValueBlock! !

!Preferences class methodsFor: 'parameters' stamp: 'AlainPlantec 1/7/2010 23:41'!
parameters
	^ Parameters ifNil: [self initializeParameters. Parameters]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
postscriptStoredAsEPS
	^ self
		valueOfFlag: #postscriptStoredAsEPS
		ifAbsent: [false]! !

!Preferences class methodsFor: 'preference-object access' stamp: 'rr 10/1/2005 15:14'!
preferenceAt: aSymbol 
	"Answer the Preference object at the given symbol, or nil if not there"

	^ self dictionaryOfPreferences  at:aSymbol  ifAbsent:[nil]! !

!Preferences class methodsFor: 'preference-object access' stamp: 'rr 10/1/2005 15:14'!
preferenceAt: aSymbol ifAbsent: aBlock 
	"Answer the Preference object at the given symbol, or the value of aBlock if not present"

	^ self dictionaryOfPreferences  at:aSymbol  ifAbsent:[aBlock value]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
preferenceBrowserWindowColor
	^ self
		valueOfFlag: #preferenceBrowserWindowColor
		ifAbsent: [Color
				r: 0.645
				g: 1.0
				b: 1.0]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
preferencesPanelWindowColor
	^ self
		valueOfFlag: #preferencesPanelWindowColor
		ifAbsent: [Color
				r: 0.645
				g: 1.0
				b: 1.0]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/10/2009 15:19'!
preserveTrash
	^ self preserveTrashSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 07:22'!
preserveTrashNoSetting
	^ false! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 15:18'!
preserveTrashSetting
	^ false! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 15:18'!
preserveTrashSetting: aBoolean
! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 15:44'!
printStandardSystemFonts
	"self printStandardSystemFonts"

	| string |
	string := String streamContents: [ :s |

	StandardFonts systemFontAspects do: [:selector |
		| font |
		font := StandardFonts perform: selector.
		s
			nextPutAll: selector; space;
			nextPutAll: font familyName; space;
			nextPutAll: (AbstractFont emphasisStringFor: font emphasis);
			nextPutAll: ' points: ';
			print: font pointSize;
			nextPutAll: ' height: ';
			print: font height;
			cr
		]].

	(StringHolder new)
		contents: string;
		openLabel: 'Current system font settings' translated.
! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/17/2009 22:48'!
promptForUpdateServer
	^ self promptForUpdateServerSetting
	! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/17/2009 22:47'!
promptForUpdateServerSetting
	^ Utilities promptForUpdateServer! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
promptOnRefactoring
	^ self
		valueOfFlag: #promptOnRefactoring
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 09:42'!
purgeUndoOnQuit
	^ self purgeUndoOnQuitSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 09:42'!
purgeUndoOnQuitSetting
	^ CommandHistory purgeUndoOnQuit! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 09:42'!
purgeUndoOnQuitSetting: aBoolean
	^ CommandHistory purgeUndoOnQuit: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 10:11'!
raiseDeprecatedWarnings
	^ self raiseDeprecatedWarningsSetting
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 10:10'!
raiseDeprecatedWarningsSetting
	^ Deprecation raiseWarning! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 10:17'!
raiseDeprecatedWarningsSetting: aBoolean
	Deprecation raiseWarning: aBoolean! !

!Preferences class methodsFor: 'settings-no-migration' stamp: 'AlainPlantec 12/17/2009 21:45'!
readDocumentAtStartup
	^ self readDocumentAtStartupSetting! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/17/2009 21:44'!
readDocumentAtStartupSetting
	^ ProjectLauncher readDocumentAtStartup! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/17/2009 21:45'!
readDocumentAtStartupSetting: aBoolean
	ProjectLauncher readDocumentAtStartup: aBoolean! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
readOnlyMode
	^ self
		valueOfFlag: #readOnlyMode
		ifAbsent: [false]! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 15:45'!
refreshFontSettings
	"Try to update all the current font settings to make things consistent."

	StandardFonts systemFontAspects  do: [:a |
		StandardFonts perform: (a,':') asSymbol with: (StandardFonts perform: a)].

	SystemWindow allSubInstancesDo: [ :s | | rawLabel |
		rawLabel := s getRawLabel.
		rawLabel owner vResizing: #spaceFill.
		rawLabel font: rawLabel font.
		s setLabel: s label.
		s replaceBoxes ].! !

!Preferences class methodsFor: 'initialization' stamp: 'ar 9/27/2005 21:49'!
removeObsolete
	"Remove obsolete preferences"
	Preference allInstancesDo:[:pref|
		pref isObsolete ifTrue:[self removePreference: pref].
	].! !

!Preferences class methodsFor: 'initialization' stamp: 'AlainPlantec 1/7/2010 23:43'!
removePreference: aSymbol
	"Remove all memory of the given preference symbol."
	
	self dictionaryOfPreferences removeKey: aSymbol ifAbsent: [].
	self parameters removeKey: aSymbol ifAbsent: [].
	(Parameters at: #PersonalDictionaryOfPreferences ifAbsent: []) 
		ifNotNil: [:personalDict | personalDict removeKey: aSymbol ifAbsent: []]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/6/2009 22:08'!
restartAlsoProceeds
	^ Debugger restartAlsoProceeds! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:11'!
restartAlsoProceedsSetting
	^ Debugger restartAlsoProceeds! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:11'!
restartAlsoProceedsSetting: aBoolean
	Debugger restartAlsoProceeds: aBoolean! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/20/2009 00:44'!
restoreDefaultFonts
	"Since this is called from menus, we can take the opportunity to prompt for missing font styles."
	"
	Preferences restoreDefaultFonts
	"	
	StandardFonts setFontsFromSpec: 
		#( #(#defaultFont: 'Bitmap DejaVu Sans' 9 ) 
			#(#codeFont: 'Bitmap DejaVu Sans' 9 ) 
			#(#listFont: 'Bitmap DejaVu Sans' 9 ) 
			#(#menuFont: 'Bitmap DejaVu Sans' 9 ) 
			#(#windowTitleFont: 'Bitmap DejaVu Sans' 12 ) 
			#(#balloonFont: 'Accuny' 10 ) 
			#(#haloFont: 'Accuny' 10 ) 
			#(#buttonFont: 'Bitmap DejaVu Sans' 9 ) ).
! !

!Preferences class methodsFor: 'menu parameters' stamp: 'StephaneDucasse 3/23/2010 20:11'!
restoreDefaultMenuParameters
	"Restore the four color choices of the original implementors of  
	MorphicMenus"

	self parameters
		at: #menuColor
		put: (Color
				r: 0.97
				g: 0.97
				b: 0.97).
	self parameters
		at: #menuBorderColor
		put: (Color
				r: 0.167
				g: 0.167
				b: 1.0).
	self parameters at: #menuBorderWidth put: 2.
	self parameters at: #menuTitleColor put: (Color
			r: 0.4
			g: 0.8
			b: 0.9) twiceDarker.
	self parameters
		at: #menuTitleBorderColor
		put: (Color
				r: 0.333
				g: 0.667
				b: 0.751).
	self parameters at: #menuTitleBorderWidth put: 1.
	self parameters
		at: #menuLineColor
		put: (Preferences menuBorderColor lighter)! !

!Preferences class methodsFor: 'misc' stamp: 'AlainPlantec 12/20/2009 00:21'!
roundedCornersString
	^ (((self valueOfFlag: #roundedWindowCorners)
		ifTrue: ['stop']
		ifFalse: ['start']) , ' rounding window corners') translated! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/13/2009 15:42'!
roundedMenuCorners
	^ self roundedMenuCornersSetting
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/13/2009 15:40'!
roundedMenuCornersSetting
	^ UITheme currentSettings preferRoundCorner! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/13/2009 15:40'!
roundedMenuCornersSetting: aBoolean
	UITheme currentSettings preferRoundCorner: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/14/2009 19:59'!
roundedWindowCorners
	^ self roundedWindowCornersSetting	! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/14/2009 19:58'!
roundedWindowCornersSetting
	^ UITheme currentSettings preferRoundCorner ! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/14/2009 19:58'!
roundedWindowCornersSetting: aBoolean
	UITheme currentSettings preferRoundCorner: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
rulesAccessSelector
	^ self
		valueOfFlag: #rulesAccessSelector
		ifAbsent: ['defaultCategorizationRules']! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
rulesGlobalName
	^ self
		valueOfFlag: #rulesGlobalName
		ifAbsent: ['AutomaticMethodCategorizer']! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
scrollBarsNarrow
	^ self
		valueOfFlag: #scrollBarsNarrow
		ifAbsent: [false]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
scrollBarsOnRight
	^ self
		valueOfFlag: #scrollBarsOnRight
		ifAbsent: [false]! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/17/2009 14:44'!
scrollBarsOnRightSetting
	^ UITheme currentSettings scrollBarsOnRight! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
scrollBarsWithoutMenuButton
	^ self
		valueOfFlag: #scrollBarsWithoutMenuButton
		ifAbsent: [false]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/17/2009 21:26'!
securityChecksEnabled
	^ self securityChecksEnabledSetting! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/17/2009 21:25'!
securityChecksEnabledSetting
	^ SecurityManager default securityChecksEnabled! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/17/2009 21:25'!
securityChecksEnabledSetting: aBoolean
	SecurityManager default securityChecksEnabled: aBoolean! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
selectiveHalos
	^ self
		valueOfFlag: #selectiveHalos
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/14/2009 14:07'!
serverMode
	^ self serverModeSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/14/2009 14:05'!
serverModeSetting
	^ WorldState serverMode! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/14/2009 14:05'!
serverModeSetting: aBoolean
	WorldState serverMode: aBoolean! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:24'!
setBalloonHelpFontTo: aFont
	StandardFonts balloonFont: aFont! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:25'!
setButtonFontTo: aFont
	StandardFonts buttonFont: aFont! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:25'!
setCodeFontTo: aFont
	"Establish the code font."
	StandardFonts codeFont: aFont! !

!Preferences class methodsFor: 'parameters' stamp: 'AlainPlantec 1/7/2010 23:43'!
setDefaultAnnotationInfo
	"Preferences setDefaultAnnotationInfo"
	^ self parameters at: #MethodAnnotations put: #(timeStamp messageCategory sendersCount implementorsCount allChangeSets)! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:25'!
setDefaultFonts: defaultFontsSpec
	"Since this is called from menus, we can take the opportunity to prompt for missing font styles."

	| fontNames map emphases |
	fontNames := defaultFontsSpec collect: [:array | array second].
	map := IdentityDictionary new.
	emphases := IdentityDictionary new.
	fontNames do: [:originalName | | decoded style response |
		decoded := TextStyle decodeStyleName: originalName.
		style := map at: originalName put: (TextStyle named: decoded second).
		emphases at: originalName put: decoded first.
		style ifNil: [map at: originalName put: (TextStyle default) ]].
	defaultFontsSpec do: [:triplet | self
		perform: triplet first
		with: (((map at: triplet second) fontOfPointSize: triplet third) emphasized: (emphases at: triplet second))]! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:27'!
setDemoFonts
	"Preferences setDemoFonts"
	|size font codeFont titleFont|

	size := UIManager default request: 'Base font size?' initialAnswer: '14'.
	size isEmptyOrNil ifTrue: [^ self].
	size := size asInteger.
	(size isNil or: [size <= 0]) ifTrue: [^ self].
	font := LogicalFont familyName: 'DejaVu Sans' pointSize: size.
	codeFont := LogicalFont familyName: 'DejaVu Sans Mono' pointSize: size.
	titleFont := LogicalFont familyName: 'DejaVu Serif' pointSize: size.

	StandardFonts
		listFont: font;
		menuFont: font;
		codeFont: codeFont;
		buttonFont: font;
		defaultFont: font;
		windowTitleFont: titleFont.! !

!Preferences class methodsFor: 'misc' stamp: 'sw 1/4/2001 06:56'!
setFlag: prefSymbol toValue: aBoolean during: aBlock
	"Set the flag to the given value for the duration of aBlock"

	| existing |
	existing := self valueOfFlag: prefSymbol.
	existing == aBoolean ifFalse: [self setPreference: prefSymbol toValue: aBoolean].
	aBlock value.
	existing == aBoolean ifFalse: [self setPreference: prefSymbol toValue: existing]! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:29'!
setListFontTo: aFont
	"Set the list font as indicated"
	StandardFonts listFont: aFont! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 1/7/2010 23:43'!
setPaintBoxButtonFontTo: aFont 
	"change the font used in the buttons in PaintBox."
	self parameters at: #paintBoxButtonFont put: aFont! !

!Preferences class methodsFor: 'parameters' stamp: 'AlainPlantec 1/7/2010 23:43'!
setParameter: paramName to: paramValue
	"Set the given field in the parameters dictionary."

	self parameters at: paramName put: paramValue! !

!Preferences class methodsFor: 'get/set' stamp: 'sw 4/12/2001 23:29'!
setPreference: prefSymbol toValue: aBoolean
	"Set the given preference to the given value, and answer that value"

	^ (self preferenceAt: prefSymbol ifAbsent: [^ aBoolean]) preferenceValue: aBoolean! !

!Preferences class methodsFor: 'initialization' stamp: 'sw 4/21/2002 05:13'!
setPreferencesFrom: listOfPairs
	"Given a list of <preferenceName, value> pairs, set preference values.  This method is tolerent of the value being supplied either a Boolean or else one of the symbols #true and #false.  Also, a new-value of #noOpinion will result in that 'preference's value not being changed."

	listOfPairs do:
		[:aPair |
			(aPair second == #noOpinion) ifFalse:
				[Preferences setPreference: aPair first toValue: ((aPair second == #true) or: [aPair second == true])]]

"
Preferences setPreferencesFrom: #(( mouseOverForKeyboardFocus false))
Preferences setPreferencesFrom: {{  #mouseOverForKeyboardFocus. true}}
"! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:33'!
setSystemFontTo: aFont
	"Establish the default text font and style"

	StandardFonts defaultFont: aFont.
! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:34'!
setWindowTitleFontTo: aFont
	"Set the window-title font to be as indicated"
	StandardFonts windowTitleFont: aFont.
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/17/2009 10:24'!
settingsMigrationCheck
	Preference allInstances do: [:p | p settingsMigrationCheck]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 23:19'!
showBoundsInHalo
	^ self showBoundsInHaloSetting
	! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 23:18'!
showBoundsInHaloSetting
	^ HaloMorph showBoundsInHalo! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 23:19'!
showBoundsInHaloSetting: aBoolean
	^ HaloMorph showBoundsInHalo: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 10:16'!
showDeprecationWarnings
	^ self showDeprecationWarningsSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 10:16'!
showDeprecationWarningsSetting
	^ Deprecation showWarning! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 10:16'!
showDeprecationWarningsSetting: aBoolean
	Deprecation showWarning: aBoolean! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
showDirectionForSketches
	^ self
		valueOfFlag: #showDirectionForSketches
		ifAbsent: [false]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
showDirectionHandles
	^ self
		valueOfFlag: #showDirectionHandles
		ifAbsent: [false]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/17/2009 21:27'!
showSecurityStatus
	^ self showSecurityStatusSetting
! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/17/2009 21:26'!
showSecurityStatusSetting
	^ SecurityManager default showSecurityStatus! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/17/2009 21:27'!
showSecurityStatusSetting: aBoolean
	SecurityManager default showSecurityStatus: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/14/2009 21:48'!
showSplitterHandles
	^ self showSplitterHandlesSetting
! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/14/2009 21:47'!
showSplitterHandlesSetting
	^ ProportionalSplitterMorph showSplitterHandles! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/14/2009 21:48'!
showSplitterHandlesSetting: aBoolean
	ProportionalSplitterMorph showSplitterHandles: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
showTextEditingState
	^ self
		valueOfFlag: #showTextEditingState
		ifAbsent: [false]! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 15:12'!
showTextEditingStateSetting
	^ PluggableTextEditorMorph showTextEditingState! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 15:13'!
showTextEditingStateSetting: aBoolean
	PluggableTextEditorMorph showTextEditingState: aBoolean! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:15'!
showWorldTaskbarSetting
	^ TaskbarMorph showTaskbar! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:15'!
showWorldTaskbarSetting: aBoolean
	TaskbarMorph showTaskbar: aBoolean! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 15:18'!
slideDismissalsToTrashSetting: aBoolean
! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/10/2009 15:21'!
smartUpdating
	^ self smartUpdatingSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/10/2009 15:20'!
smartUpdatingSetting
	^ CodeHolder smartUpdating
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 10:48'!
smartUpdatingSetting: aBoolean
	CodeHolder smartUpdating: aBoolean
! !

!Preferences class methodsFor: 'misc' stamp: 'marcus.denker 9/19/2008 17:01'!
soundEnablingString
	^ self soundsEnabled
		ifFalse:
			['Turn sound on' translated]
		ifTrue:
			['Turn sound off' translated]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
soundQuickStart
	^ self
		valueOfFlag: #soundQuickStart
		ifAbsent: [false]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
soundStopWhenDone
	^ self
		valueOfFlag: #soundStopWhenDone
		ifAbsent: [false]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
soundTheme
	^ self
		valueOfFlag: #soundTheme
		ifAbsent: [SoundTheme]! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 1/10/2010 08:01'!
soundThemeSetting
	^ PolymorphSystemSettings soundThemeClass! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 1/10/2010 08:01'!
soundThemeSetting: aClass
	PolymorphSystemSettings soundThemeClass: aClass! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
soundsEnabled
	^ self
		valueOfFlag: #soundsEnabled
		ifAbsent: [true]! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:28'!
soundsEnabledSetting
	^ SoundSettings soundEnabled! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:28'!
soundsEnabledSetting: aBoolean
	SoundSettings soundEnabled: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'mir 11/10/2003 14:28'!
standaloneSecurityChecksEnabled
 	^ self
 		valueOfFlag: #standaloneSecurityChecksEnabled
 		ifAbsent: [false]! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:55'!
standardBalloonHelpFont
	^	StandardFonts balloonFont! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:34'!
standardButtonFont
	"Answer an attractive font to use for buttons"
	^ StandardFonts buttonFont! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:35'!
standardCodeFont
	"Answer the font to be used in code"
	
	^StandardFonts codeFont! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:35'!
standardDefaultTextFont
	^StandardFonts defaultFont! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:35'!
standardHaloLabelFont
	"Answer the font to be used in the eToys environment"
	^StandardFonts haloFont! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:35'!
standardListFont
	"Answer the font to be used in lists"
	^StandardFonts listFont! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:36'!
standardMenuFont
	"Answer the font to be used in menus"
	^StandardFonts menuFont! !

!Preferences class methodsFor: 'FreeType-addition' stamp: 'AlainPlantec 12/6/2009 19:36'!
standardSystemFont
	"Answer the standard system font "
	^StandardFonts defaultFont! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/17/2009 21:28'!
startInUntrustedDirectory
	^ self startInUntrustedDirectorySetting
	! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/17/2009 21:27'!
startInUntrustedDirectorySetting
	^ SecurityManager default startInUntrustedDirectory! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/17/2009 21:28'!
startInUntrustedDirectorySetting: aBoolean
	SecurityManager default startInUntrustedDirectory: aBoolean! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/18/2009 14:22'!
subPixelRenderColorFonts
	^  StrikeFont subPixelRenderColorFonts! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/18/2009 14:22'!
subPixelRenderFonts
	^ StrikeFont subPixelRenderFonts! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/17/2009 09:59'!
swapControlAndAltKeys
	^ self swapControlAndAltKeysSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/17/2009 09:59'!
swapControlAndAltKeysSetting
	^ InputEventSensor controlAltKeyDecodePolicy = #Swapped
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/17/2009 10:02'!
swapControlAndAltKeysSetting: aBoolean
	aBoolean ifTrue: [InputEventSensor controlAltKeyDecodePolicy: #Swapped]
! !

!Preferences class methodsFor: 'standard queries' stamp: 'adrian-lienhard 5/22/2009 10:41'!
swapMouseButtons
	^ self
		valueOfFlag: #swapMouseButtons
		ifAbsent: [
			OSPlatform current platformFamily ~= #Windows ]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
syntaxHighlightingAsYouType
	^ self
		valueOfFlag: #syntaxHighlightingAsYouType
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
syntaxHighlightingAsYouTypeAnsiAssignment
	^ self
		valueOfFlag: #syntaxHighlightingAsYouTypeAnsiAssignment
		ifAbsent: [false]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
syntaxHighlightingAsYouTypeLeftArrowAssignment
	^ self
		valueOfFlag: #syntaxHighlightingAsYouTypeLeftArrowAssignment
		ifAbsent: [false]! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
systemWindowEmbedOK
	^ self
		valueOfFlag: #systemWindowEmbedOK
		ifAbsent: [false]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/10/2009 15:25'!
tabAmongFields
	^ self tabAmongFieldsSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/21/2009 12:15'!
tabAmongFieldsSetting
	^ UITheme currentSettings tabAmongFields! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/21/2009 12:15'!
tabAmongFieldsSetting: aBoolean
	UITheme currentSettings tabAmongFields: aBoolean! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
testRunnerWindowColor
	^ self
		valueOfFlag: #testRunnerWindowColor
		ifAbsent: [Color
				r: 0.65
				g: 0.753
				b: 0.976]! !

!Preferences class methodsFor: 'text highlighting' stamp: 'AlainPlantec 1/7/2010 23:43'!
textHighlightColor
	^ self parameters at: #textHighlightColor! !

!Preferences class methodsFor: 'text highlighting' stamp: 'AlainPlantec 1/7/2010 23:43'!
textHighlightColor: aColor
	self parameters at: #textHighlightColor put: aColor! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 10:51'!
tinyDisplay
	^ self tinyDisplaySetting
! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/11/2009 10:50'!
tinyDisplaySetting
	^ DisplayScreen tiny! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/11/2009 10:51'!
tinyDisplaySetting: aBoolean
	DisplayScreen tiny: aBoolean
! !

!Preferences class methodsFor: 'get/set' stamp: 'hpt 9/26/2004 16:50'!
togglePreference: prefSymbol
	"Toggle the given preference. prefSymbol must be of a boolean preference"
	(self preferenceAt: prefSymbol ifAbsent: [self error: 'unknown preference: ', prefSymbol]) togglePreferenceValue! !

!Preferences class methodsFor: 'misc' stamp: 'AlainPlantec 12/7/2009 15:06'!
toggleSoundEnabling
     SoundSettings soundEnabled: SoundSettings soundEnabled not! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
transcriptWindowColor
	^ self
		valueOfFlag: #transcriptWindowColor
		ifAbsent: [Color
				r: 1.0
				g: 0.8
				b: 0.4]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
uiTheme
	^ self
		valueOfFlag: #uiTheme
		ifAbsent: [UIThemeStandardSqueak]! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 1/10/2010 07:42'!
uiThemeSetting
	^ PolymorphSystemSettings uiThemeClass ! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 1/10/2010 07:42'!
uiThemeSetting: aClass
	PolymorphSystemSettings uiThemeClass: aClass! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/10/2009 15:39'!
unlimitedPaintArea
	^ self unlimitedPaintAreaSetting
! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/10/2009 15:39'!
unlimitedPaintAreaSetting
	^ false! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/10/2009 15:39'!
unlimitedPaintAreaSetting: aBoolean
	! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/17/2009 22:52'!
updateFromServerAtStartup
	^ self updateFromServerAtStartupSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/17/2009 22:51'!
updateFromServerAtStartupSetting
	^ AutoStart updateFromServerAtStartup! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/17/2009 22:52'!
updateFromServerAtStartupSetting: aBoolean
	AutoStart updateFromServerAtStartup: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/17/2009 22:55'!
updateSavesFile
	^ self updateSavesFileSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/17/2009 22:55'!
updateSavesFileSetting
	^ Utilities updateSavesFile! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/17/2009 23:00'!
upgradeIsMerge
	^ self upgradeIsMergeSetting
	! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/17/2009 23:00'!
upgradeIsMergeSetting
	^ MCConfiguration upgradeIsMerge ! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/17/2009 23:00'!
upgradeIsMergeSetting: aBoolean
	MCConfiguration upgradeIsMerge: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 11:01'!
useLocale
	^ self useLocaleSetting
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 11:00'!
useLocaleSetting
	^ Locale activated! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 11:01'!
useLocaleSetting: aBoolean
	Locale activated: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
useNewDiffToolsForMC
	^ self
		valueOfFlag: #useNewDiffToolsForMC
		ifAbsent: [true]! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:03'!
useNewDiffToolsForMCSetting
	^ PSMCPatchMorph usedByDefault! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:04'!
useNewDiffToolsForMCSetting: aBoolean
	PSMCPatchMorph usedByDefault: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
useRBASTForPrettyPrint
	^ self
		valueOfFlag: #useRBASTForPrettyPrint
		ifAbsent: [false]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
useSmartLabels
	^ self
		valueOfFlag: #useSmartLabels
		ifAbsent: [false]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 15:07'!
useThemeSounds
	^ SoundSettings useThemeSounds! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:29'!
useThemeSoundsSetting
	^ SoundSettings useThemeSounds! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:29'!
useThemeSoundsSetting: aBoolean
	SoundSettings useThemeSounds: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 09:07'!
useUndo
	^ self useUndoSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 09:07'!
useUndoSetting
	^ CommandHistory useUndo! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 09:07'!
useUndoSetting: aBoolean
	CommandHistory useUndo: aBoolean! !

!Preferences class methodsFor: 'get/set' stamp: 'hpt 9/26/2004 16:49'!
valueOfFlag: aFlagName
	"Utility method for all the preferences that are boolean, and for backward compatibility"
	^self valueOfPreference: aFlagName ifAbsent: [false].! !

!Preferences class methodsFor: 'get/set' stamp: 'hpt 9/26/2004 16:48'!
valueOfFlag: aFlagName ifAbsent: booleanValuedBlock
	"the same as in #valueOfFlag:"
	^self valueOfPreference: aFlagName ifAbsent: booleanValuedBlock.! !

!Preferences class methodsFor: 'get/set' stamp: 'hpt 9/26/2004 16:49'!
valueOfPreference: aPreferenceSymbol
	"Answer the value of the given preference"
	^self valueOfPreference: aPreferenceSymbol ifAbsent: []! !

!Preferences class methodsFor: 'get/set' stamp: 'hpt 9/26/2004 16:49'!
valueOfPreference: aPreferenceSymbol ifAbsent: booleanValuedBlock
	"Answer the value of the given preference"
	^ (self preferenceAt: aPreferenceSymbol ifAbsent: [^ booleanValuedBlock value]) preferenceValue! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
versionsBrowserWindowColor
	^ self
		valueOfFlag: #versionsBrowserWindowColor
		ifAbsent: [Color
				r: 0.869
				g: 0.753
				b: 1.0]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/6/2009 22:14'!
visualExplorer
	^ ObjectExplorer showIcons! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:12'!
visualExplorerSetting
	^ ObjectExplorer showIcons! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:12'!
visualExplorerSetting: aBoolean
	^ ObjectExplorer showIcons: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
visualizations
	^ self
		valueOfFlag: #visualizations
		ifAbsent: [true]! !

!Preferences class methodsFor: 'misc' stamp: 'MiguelCoba 7/25/2009 02:19'!
wantsChangeSetLogging
	"Answer whether method changes in the receiver should be logged to current change set.  This circumlocution avoids such logging for programmatically-compiled methods in Preferences, removing an annoyance"

	^ Author fullNamePerSe  ~= 'programmatic'! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/17/2009 21:29'!
warnAboutInsecureContent
	^ self warnAboutInsecureContentSetting
! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/17/2009 21:28'!
warnAboutInsecureContentSetting
	^ SecurityManager default warnAboutInsecureContent! !

!Preferences class methodsFor: 'settings-semi-migration' stamp: 'AlainPlantec 12/17/2009 21:29'!
warnAboutInsecureContentSetting: aBoolean
	SecurityManager default warnAboutInsecureContent: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 14:41'!
warnIfNoChangesFile
	^ self warnIfNoChangesFileSetting
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 14:41'!
warnIfNoChangesFileSetting
	^ SmalltalkImage checkChangesFileAvailability! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 14:41'!
warnIfNoChangesFileSetting: aBoolean
	SmalltalkImage checkChangesFileAvailability: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 14:37'!
warnIfNoSourcesFile
	^ self warnIfNoSourcesFileSetting! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 14:36'!
warnIfNoSourcesFileSetting
	^ SmalltalkImage checkSourcesFileAvailability! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 14:37'!
warnIfNoSourcesFileSetting: aBoolean
	SmalltalkImage checkSourcesFileAvailability: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
windowAnimation
	^ self
		valueOfFlag: #windowAnimation
		ifAbsent: [true]! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
windowAnimationDelay
	^ self
		valueOfFlag: #windowAnimationDelay
		ifAbsent: [10]! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/15/2009 10:43'!
windowAnimationDelaySetting
	^ UITheme currentAnimationSettings delay! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/15/2009 10:43'!
windowAnimationDelaySetting: anInteger
	^ UITheme currentAnimationSettings delay: anInteger! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/15/2009 10:28'!
windowAnimationSetting
	^ UITheme currentAnimationSettings useAnimation! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/15/2009 10:33'!
windowAnimationSetting: aBoolean
	UITheme currentAnimationSettings useAnimation: aBoolean! !

!Preferences class methodsFor: 'standard queries' stamp: ''!
windowAnimationSteps
	^ self
		valueOfFlag: #windowAnimationSteps
		ifAbsent: [15]! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/15/2009 10:45'!
windowAnimationStepsSetting
	^ UITheme currentAnimationSettings numberOfSteps ! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/15/2009 10:45'!
windowAnimationStepsSetting: anInteger
	UITheme currentAnimationSettings numberOfSteps: anInteger! !

!Preferences class methodsFor: 'window colors' stamp: 'lr 3/14/2010 21:13'!
windowColorFor: aModelClassName
	| classToCheck prefSymbol |
	self deprecated: 'Define a #preferredColor method in the class side of your model class instead'.
	self checkForWindowColors.
	classToCheck := Smalltalk globals at: aModelClassName.
	prefSymbol := self windowColorPreferenceForClassNamed: classToCheck name.
	[ classToCheck ~~ Object and: [ (self preferenceAt: prefSymbol) isNil ] ]
		whileTrue: [ 
			classToCheck := classToCheck superclass.
			prefSymbol := self windowColorPreferenceForClassNamed: classToCheck name ].
	^ self valueOfPreference: prefSymbol ifAbsent: [ Color white ]! !

!Preferences class methodsFor: 'window colors' stamp: 'AlainPlantec 12/16/2009 21:28'!
windowColorPreferenceForClassNamed: aClassName
	self deprecated: 'Not used since Settings integration'! !

!Preferences class methodsFor: 'fonts' stamp: 'AlainPlantec 12/6/2009 19:38'!
windowTitleFont
	"Answer the standard font to use for window titles"
	^StandardFonts windowTitleFont! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
windowsActiveOnFirstClick
	^ self
		valueOfFlag: #windowsActiveOnFirstClick
		ifAbsent: [false]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/11/2009 13:40'!
wordStyleCursorMovement
	^ self wordStyleCursorMovementSetting
! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 13:39'!
wordStyleCursorMovementSetting
	^ ParagraphEditor walkAlongDisplayedLine.! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/11/2009 13:40'!
wordStyleCursorMovementSetting: aBoolean
	ParagraphEditor walkAlongDisplayedLine: aBoolean! !

!Preferences class methodsFor: 'settings-no-migration' stamp: ''!
workspaceWindowColor
	^ self
		valueOfFlag: #workspaceWindowColor
		ifAbsent: [Color
				r: 1.0
				g: 1.0
				b: 0.8]! !

!Preferences class methodsFor: 'standard queries' stamp: 'AlainPlantec 12/7/2009 09:13'!
worldTaskbarWindowPreview
	^ TaskbarMorph showWindowPreview ! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:16'!
worldTaskbarWindowPreviewSetting
	^ TaskbarMorph showWindowPreview ! !

!Preferences class methodsFor: 'settings-migration' stamp: 'AlainPlantec 12/8/2009 11:16'!
worldTaskbarWindowPreviewSetting: aBoolean
	TaskbarMorph showWindowPreview: aBoolean! !

!Preferences methodsFor: 'look in class' stamp: 'di 12/4/1999 15:11'!
seeClassSide
	"All the code for Preferences is on the class side"! !
